==> relengapi-0.3.tar.gz: relengapi-0.3/relengapi/blueprints/badpenny/execution.py <==
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

import json
import logging
import traceback

from flask import current_app
from relengapi.blueprints.badpenny import tables
from relengapi.lib import badpenny
from relengapi.lib import celery
from relengapi.lib import time

logger = logging.getLogger(__name__)


def submit_job(task_name, job_id):
    # make a request via celery, but ignore the result
    _run_job.delay(task_name, job_id)


class JobStatus(object):

    def __init__(self, task_name, job):
        self.task_name = task_name
        self.job = job
        self._log_output = []

    def log_message(self, message):
        """Add MESSAGE to the log output of the job"""
        self._log_output.append(message)

    def _start(self):
        self.job.started_at = time.now()
        current_app.db.session('relengapi').commit()

    def _finish(self, successful, result):
        self.job.completed_at = time.now()
        self.job.successful = successful
        self.job.result = json.dumps(result)
        if self._log_output:
            self.job.logs = u'\n'.join(self._log_output)
        current_app.db.session('relengapi').commit()


@celery.task()
def _run_job(task_name, job_id):
    task = badpenny.Task.get(task_name)
    if not task:
        logger.warning("No such task %r; request dropped", task_name)
        return

    job = tables.BadpennyJob.query.filter(
        tables.BadpennyJob.id == job_id).first()
    if not job:
        logger.warning("No job with id %r; request dropped", job_id)
        return

    job_status = JobStatus(task_name, job)

    job_status._start()

    try:
        result = task.task_func(job_status)
    except Exception:
        logger.exception("Job %r failed", job_id)
        job_status.log_message(traceback.format_exc())
        job_status._finish(successful=False, result=None)
        return

    job_status._finish(successful=True, result=result)

==> relengapi-1.1.1.tar.gz: relengapi-1.1.1/relengapi/blueprints/badpenny/execution.py <==
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

import logging
import traceback

from flask import current_app
from relengapi.blueprints.badpenny import tables
from relengapi.lib import badpenny
from relengapi.lib import celery
from relengapi.lib import time

logger = logging.getLogger(__name__)


def submit_job(task_name, job_id):
    # make a request via celery, but ignore the result
    _run_job.delay(task_name, job_id)


class JobStatus(object):

    def __init__(self, task_name, job):
        self.task_name = task_name
        self.job = job
        self._log_output = []

    def log_message(self, message):
        """Add MESSAGE to the log output of the job"""
        self._log_output.append(message)

    def _start(self):
        self.job.started_at = time.now()
        current_app.db.session('relengapi').commit()

    def _finish(self, successful):
        session = current_app.db.session('relengapi')

        self.job.completed_at = time.now()
        self.job.successful = successful
        if self._log_output:
            content = u'\n'.join(self._log_output)
            l = tables.BadpennyJobLog(id=self.job.id, content=content)
            session.add(l)
        session.commit()


@celery.task()
def _run_job(task_name, job_id):
    task = badpenny.Task.get(task_name)
    if not task:
        logger.warning("No such task %r; request dropped", task_name)
        return

    job = tables.BadpennyJob.query.filter(
        tables.BadpennyJob.id == job_id).first()
    if not job:
        logger.warning("No job with id %r; request dropped", job_id)
        return

    job_status = JobStatus(task_name, job)

    job_status._start()

    try:
        task.task_func(job_status)
    except Exception:
        logger.exception("Job %r failed", job_id)
        job_status.log_message(traceback.format_exc())
        job_status._finish(successful=False)
        return

    job_status._finish(successful=True)
